﻿/****************************************************************************
//
//                I N F O S I G H T    C O R P O R A T I O N
//
//                       SampleExtendedProtocolForm.cs
//
//		    This module contains the form for testing the sample Extended
//      Protocol functions.
//
//
//
//   CREATED BY :      Joseph F. Muscarella
//                     InfoSight Corporation
//                     10/25/2016
//
//
//
//   MODIFICATION HISTORY
//   VERSION    DATE    INITIALS       DESCRIPTION
//   ======= ========== ========  ===========================================
//
//
//  This software is licensed under The MIT License (MIT)
//
//	Copyright (c) 2016  InfoSight Corporation
// 
//  Permission is hereby granted, free of charge, to any person obtaining a copy 
//  of this software and associated documentation files (the "Software"), to deal 
//  in the Software without restriction, including without limitation the rights 
//  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
//  of the Software, and to permit persons to whom the Software is furnished to do 
//  so, subject to the following conditions:
//
//  The above copyright notice and this permission notice shall be included in all 
//  copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, 
//  INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//  PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
//  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
//  CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
//  OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
****************************************************************************/

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace SampleExtendedProtocolApplication
{
    public partial class SampleExtendedProtocolForm : Form
    {
        /****************************************************************************
        //
        //   SampleExtendedProtocolForm
        //
        //   Syntax			:	SampleExtendedProtocolForm();
        //
        //   Arguments		:	none
        //
        //   Returns		:	nothing
        //
        //   Description	:	This is the constructor for the form.
        //
        ****************************************************************************/    
        public SampleExtendedProtocolForm()
        {
            InitializeComponent();
        }

        /****************************************************************************
        //
        //   COMTestButton_Click
        //
        //   Syntax			:	void    COMTestButton_Click(sender e);
        //
        //   Arguments		:	object      Sender  : the sender of the event.
        //                      EventArgs   e       : the arguments.
        //
        //   Returns		:	nothing
        //
        //   Description	:	This event handler fires when the user clicks the
        //          COM Test button.  Using the settings from the RemoteIPAddressTextBox
        //          and the RemotePortNumberTextBox, attempt to communicate to the remote
        //          marker to obtain its version information.  We send message type 'V'
        //          with no data in the Data Text field and the reply from the marker
        //          will contain the version information. Put the reply in the
        //          ReplyMessageTextBox and the status result in the StatusMessageTextBox.
        //
        ****************************************************************************/
        private void COMTestButton_Click(object sender, EventArgs e)
        {
            StatusMessageTextBox.Text   = "Sending...";
            StatusMessageTextBox.Refresh();
            ReplyMessageTextBox.Text    = "";
            ReplyMessageTextBox.Refresh();

            string  reply_text  = "";
            string  error_msg   = ExtendedProtocolSynchronousClientSocket.SendMessage(RemoteIPAddressTextBox.Text,
                                                                                        Convert.ToUInt16(RemotePortNumberTextBox.Text),
                                                                                        (byte)'V',
                                                                                        "",
                                                                                        out reply_text);
            StatusMessageTextBox.Text    = error_msg;
            ReplyMessageTextBox.Text    = reply_text;
        }

        /****************************************************************************
        //
        //   SendOnTimeButton_Click
        //
        //   Syntax			:	void    SendOnTimeButton_Click(sender e);
        //
        //   Arguments		:	object      Sender  : the sender of the event.
        //                      EventArgs   e       : the arguments.
        //
        //   Returns		:	nothing
        //
        //   Description	:	This event handler fires when the user clicks the
        //          Send On Time button.  Using the settings from the RemoteIPAddressTextBox
        //          and the RemotePortNumberTextBox, attempt to communicate to the remote
        //          marker to send the "On Time" marker setting.  We send message type 'P'
        //          with the on-time data in the Data Text field. The reply from the marker
        //          should be empty. Put the reply in the ReplyMessageTextBox and the 
        //          status result in the StatusMessageTextBox.
        //
        ****************************************************************************/
        private void SendOnTimeButton_Click(object sender, EventArgs e)
        {
            StatusMessageTextBox.Text   = "Sending...";
            StatusMessageTextBox.Refresh();
            ReplyMessageTextBox.Text    = "";
            ReplyMessageTextBox.Refresh();

            // Convert the text entry for on-time into an unsigned integer and then
            // back into a text string. This will ensure the input is a valid number.

            UInt16  on_time_value   = Convert.ToUInt16(OnTimeTextBox.Text);
            string  on_time_str     = on_time_value.ToString();

            // Build the message text. This consists of the parameter group name "MKR" 
            // and the parameter name for on-time "O1". A TAB character separates the fields.

            string  message_text    = "MKR\tO1=" + on_time_str;
            string  reply_text      = "";
            string  error_msg       = ExtendedProtocolSynchronousClientSocket.SendMessage(RemoteIPAddressTextBox.Text,
                                                                                          Convert.ToUInt16(RemotePortNumberTextBox.Text),
                                                                                          (byte)'P',
                                                                                          message_text,
                                                                                          out reply_text);
            StatusMessageTextBox.Text   = error_msg;
            ReplyMessageTextBox.Text    = reply_text;
        }

        /****************************************************************************
        //
        //   SendMessagesButton_Click
        //
        //   Syntax			:	void    SendMessagesButton_Click(sender e);
        //
        //   Arguments		:	object      Sender  : the sender of the event.
        //                      EventArgs   e       : the arguments.
        //
        //   Returns		:	nothing
        //
        //   Description	:	This event handler fires when the user clicks the
        //          Send Messages button.  Using the settings from the RemoteIPAddressTextBox
        //          and the RemotePortNumberTextBox, attempt to communicate to the remote
        //          marker to send the messages.  We send message type '0' (ASCII zero, 0x30)
        //          with the message data in the Data Text field. The message text consists
        //          of the optional message filename and the individual messages all
        //          separated by the TAB character.   The reply from the marker
        //          contains the same message string echoed back. Put the reply in the 
        //          ReplyMessageTextBox and the status result in the StatusMessageTextBox.
        //
        ****************************************************************************/
        private void SendMessagesButton_Click(object sender, EventArgs e)
        {
            StatusMessageTextBox.Text   = "Sending...";
            StatusMessageTextBox.Refresh();
            ReplyMessageTextBox.Text    = "";
            ReplyMessageTextBox.Refresh();

            // Build the message text consisting of the message file name (the name
            // of the message file in the marker) followed by the lines of text, each
            // separated from the rest with a TAB character.
            // If the filename is empty, the marker will use the currently assigned message file.

            string  message_text    = MessageFileNameTextBox.Text + "\t" +
                                      MessageTextBox1.Text + "\t" +
                                      MessageTextBox2.Text + "\t" +
                                      MessageTextBox3.Text + "\t" +
                                      MessageTextBox4.Text;

            string  reply_text      = "";
            string  error_msg       = ExtendedProtocolSynchronousClientSocket.SendMessage(RemoteIPAddressTextBox.Text,
                                                                                          Convert.ToUInt16(RemotePortNumberTextBox.Text),
                                                                                          (byte)'0',
                                                                                          message_text,
                                                                                          out reply_text);
            StatusMessageTextBox.Text   = error_msg;
            ReplyMessageTextBox.Text    = reply_text;
        }

    }
}
